==> rui-0.1.1.jar: rui-demo/public/js/compiled/demo-min/out/rui/alerts/components.js <==
// Compiled by ClojureScript 1.9.946 {:static-fns true, :optimize-constants true}
goog.provide('rui.alerts.components');
goog.require('cljs.core');
goog.require('cljs.core.constants');
goog.require('ccn.core');
/**
 * Constructs Bootstrap's alert component, takes `twbs-modifiers` as first argument and rest is taken as `children`
 */
rui.alerts.components.alert = (function rui$alerts$components$alert(var_args){
var args__9237__auto__ = [];
var len__9230__auto___14967 = arguments.length;
var i__9231__auto___14969 = (0);
while(true){
if((i__9231__auto___14969 < len__9230__auto___14967)){
args__9237__auto__.push((arguments[i__9231__auto___14969]));

var G__14970 = (i__9231__auto___14969 + (1));
i__9231__auto___14969 = G__14970;
continue;
} else {
}
break;
}

var argseq__9238__auto__ = ((((1) < args__9237__auto__.length))?(new cljs.core.IndexedSeq(args__9237__auto__.slice((1)),(0),null)):null);
return rui.alerts.components.alert.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__9238__auto__);
});

rui.alerts.components.alert.cljs$core$IFn$_invoke$arity$variadic = (function (twbs_modifiers,children){
return cljs.core.into.cljs$core$IFn$_invoke$arity$2(new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.cst$kw$div,new cljs.core.PersistentArrayMap(null, 2, [cljs.core.cst$kw$class,ccn.core.twbs("alert",twbs_modifiers),cljs.core.cst$kw$role,"alert"], null)], null),children);
});

rui.alerts.components.alert.cljs$lang$maxFixedArity = (1);

rui.alerts.components.alert.cljs$lang$applyTo = (function (seq14956){
var G__14957 = cljs.core.first(seq14956);
var seq14956__$1 = cljs.core.next(seq14956);
return rui.alerts.components.alert.cljs$core$IFn$_invoke$arity$variadic(G__14957,seq14956__$1);
});

rui.alerts.components.alert_primary = cljs.core.partial.cljs$core$IFn$_invoke$arity$2(rui.alerts.components.alert,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, ["primary"], null));
rui.alerts.components.alert_secondary = cljs.core.partial.cljs$core$IFn$_invoke$arity$2(rui.alerts.components.alert,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, ["secondary"], null));
rui.alerts.components.alert_success = cljs.core.partial.cljs$core$IFn$_invoke$arity$2(rui.alerts.components.alert,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, ["success"], null));
rui.alerts.components.alert_danger = cljs.core.partial.cljs$core$IFn$_invoke$arity$2(rui.alerts.components.alert,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, ["danger"], null));
rui.alerts.components.alert_warning = cljs.core.partial.cljs$core$IFn$_invoke$arity$2(rui.alerts.components.alert,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, ["warning"], null));
rui.alerts.components.alert_info = cljs.core.partial.cljs$core$IFn$_invoke$arity$2(rui.alerts.components.alert,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, ["info"], null));
rui.alerts.components.alert_light = cljs.core.partial.cljs$core$IFn$_invoke$arity$2(rui.alerts.components.alert,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, ["light"], null));
rui.alerts.components.alert_dark = cljs.core.partial.cljs$core$IFn$_invoke$arity$2(rui.alerts.components.alert,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, ["dark"], null));

==> rui-0.14.0.jar: rui-demo/public/js/compiled/demo-min/out/rui/alerts/components.js <==
// Compiled by ClojureScript 1.10.339 {:static-fns true, :optimize-constants true}
goog.provide('rui.alerts.components');
goog.require('cljs.core');
goog.require('cljs.core.constants');
goog.require('ccn.core');
/**
 * Constructs Bootstrap's alert component, takes `twbs-modifiers` as first argument and rest is taken as `children`
 */
rui.alerts.components.alert = (function rui$alerts$components$alert(var_args){
var args__4534__auto__ = [];
var len__4531__auto___5641 = arguments.length;
var i__4532__auto___5642 = (0);
while(true){
if((i__4532__auto___5642 < len__4531__auto___5641)){
args__4534__auto__.push((arguments[i__4532__auto___5642]));

var G__5645 = (i__4532__auto___5642 + (1));
i__4532__auto___5642 = G__5645;
continue;
} else {
}
break;
}

var argseq__4535__auto__ = ((((1) < args__4534__auto__.length))?(new cljs.core.IndexedSeq(args__4534__auto__.slice((1)),(0),null)):null);
return rui.alerts.components.alert.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__4535__auto__);
});

rui.alerts.components.alert.cljs$core$IFn$_invoke$arity$variadic = (function (twbs_modifiers,children){
return cljs.core.into.cljs$core$IFn$_invoke$arity$2(new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.cst$kw$div,new cljs.core.PersistentArrayMap(null, 2, [cljs.core.cst$kw$class,ccn.core.twbs("alert",twbs_modifiers),cljs.core.cst$kw$role,"alert"], null)], null),children);
});

rui.alerts.components.alert.cljs$lang$maxFixedArity = (1);

/** @this {Function} */
rui.alerts.components.alert.cljs$lang$applyTo = (function (seq5638){
var G__5639 = cljs.core.first(seq5638);
var seq5638__$1 = cljs.core.next(seq5638);
var self__4518__auto__ = this;
return self__4518__auto__.cljs$core$IFn$_invoke$arity$variadic(G__5639,seq5638__$1);
});

rui.alerts.components.alert_primary = cljs.core.partial.cljs$core$IFn$_invoke$arity$2(rui.alerts.components.alert,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, ["primary"], null));
rui.alerts.components.alert_secondary = cljs.core.partial.cljs$core$IFn$_invoke$arity$2(rui.alerts.components.alert,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, ["secondary"], null));
rui.alerts.components.alert_success = cljs.core.partial.cljs$core$IFn$_invoke$arity$2(rui.alerts.components.alert,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, ["success"], null));
rui.alerts.components.alert_danger = cljs.core.partial.cljs$core$IFn$_invoke$arity$2(rui.alerts.components.alert,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, ["danger"], null));
rui.alerts.components.alert_warning = cljs.core.partial.cljs$core$IFn$_invoke$arity$2(rui.alerts.components.alert,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, ["warning"], null));
rui.alerts.components.alert_info = cljs.core.partial.cljs$core$IFn$_invoke$arity$2(rui.alerts.components.alert,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, ["info"], null));
rui.alerts.components.alert_light = cljs.core.partial.cljs$core$IFn$_invoke$arity$2(rui.alerts.components.alert,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, ["light"], null));
rui.alerts.components.alert_dark = cljs.core.partial.cljs$core$IFn$_invoke$arity$2(rui.alerts.components.alert,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, ["dark"], null));
